# W3U - web3 utils

Some convenience functions for web3 python developing.

Such as:

* Getting token address given token symbol and decimals
* Getting token symbol given token address and decimals 
* Getting all transactions involving a certain account from Etherscan
* Getting the abi for a certain address from Etherscan


